import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { ProjectGczxVO, ProjectGczxForm, ProjectGczxQuery } from '@/api/project/projectGczx/types';

/**
 * 查询工程咨询列表
 * @param query
 * @returns {*}
 */

export const listProjectGczx = (query?: ProjectGczxQuery): AxiosPromise<ProjectGczxVO[]> => {
  return request({
    url: '/project/projectGczx/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询工程咨询详细
 * @param id
 */
export const getProjectGczx = (id: string | number): AxiosPromise<ProjectGczxVO> => {
  return request({
    url: '/project/projectGczx/' + id,
    method: 'get'
  });
};

/**
 * 新增工程咨询
 * @param data
 */
export const addProjectGczx = (data: ProjectGczxForm) => {
  return request({
    url: '/project/projectGczx',
    method: 'post',
    data: data
  });
};

/**
 * 修改工程咨询
 * @param data
 */
export const updateProjectGczx = (data: ProjectGczxForm) => {
  return request({
    url: '/project/projectGczx',
    method: 'put',
    data: data
  });
};

/**
 * 删除工程咨询
 * @param id
 */
export const delProjectGczx = (id: string | number | Array<string | number>) => {
  return request({
    url: '/project/projectGczx/' + id,
    method: 'delete'
  });
};
