import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { ProjectQgcVO, ProjectQgcForm, ProjectQgcQuery } from '@/api/project/projectQgc/types';

/**
 * 查询全过程咨询列表
 * @param query
 * @returns {*}
 */

export const listProjectQgc = (query?: ProjectQgcQuery): AxiosPromise<ProjectQgcVO[]> => {
  return request({
    url: '/project/projectQgc/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询全过程咨询详细
 * @param id
 */
export const getProjectQgc = (id: string | number): AxiosPromise<ProjectQgcVO> => {
  return request({
    url: '/project/projectQgc/' + id,
    method: 'get'
  });
};

/**
 * 新增全过程咨询
 * @param data
 */
export const addProjectQgc = (data: ProjectQgcForm) => {
  return request({
    url: '/project/projectQgc',
    method: 'post',
    data: data
  });
};

/**
 * 修改全过程咨询
 * @param data
 */
export const updateProjectQgc = (data: ProjectQgcForm) => {
  return request({
    url: '/project/projectQgc',
    method: 'put',
    data: data
  });
};

/**
 * 删除全过程咨询
 * @param id
 */
export const delProjectQgc = (id: string | number | Array<string | number>) => {
  return request({
    url: '/project/projectQgc/' + id,
    method: 'delete'
  });
};
